Index: main/plugin-cms/resources/js/Ametys/cms/uihelper/CreateContent.i18n.js
===================================================================
--- main/plugin-cms/resources/js/Ametys/cms/uihelper/CreateContent.i18n.js (revision 28821)
+++ main/plugin-cms/resources/js/Ametys/cms/uihelper/CreateContent.i18n.js (working copy)
@@ -466,7 +466,7 @@
this._fullContents,
null,
null,
- this._box.getEl()
+ this._box
);
}
});
Index: main/plugin-cms/resources/js/Ametys/plugins/cms/content/actions/ArchiveContentAction.i18n.js
===================================================================
--- main/plugin-cms/resources/js/Ametys/plugins/cms/content/actions/ArchiveContentAction.i18n.js (revision 28821)
+++ main/plugin-cms/resources/js/Ametys/plugins/cms/content/actions/ArchiveContentAction.i18n.js (working copy)
@@ -117,7 +117,8 @@
{
var url = 'archives/archive/' + actionId;
- this._waitMsg = new Ext.LoadMask({target: Ext.getBody(), msg: "", msgCls: 'ametys-mask-unloading'});
+ var viewport = Ext.ComponentQuery.query('viewport')[0];
+ this._waitMsg = new Ext.LoadMask({target: viewport, msg: "", msgCls: 'ametys-mask-unloading'});
this._waitMsg.show();
var contentIds = [];
@@ -224,7 +225,8 @@
{
var url = 'archives/unarchive/' + actionId;
- this._waitMsg = new Ext.LoadMask({target: Ext.getBody(), msg: "", msgCls: 'ametys-mask-unloading'});
+ var viewport = Ext.ComponentQuery.query('viewport')[0];
+ this._waitMsg = new Ext.LoadMask({target: viewport, msg: "", msgCls: 'ametys-mask-unloading'});
this._waitMsg.show();
var contentIds = [];
Index: main/plugin-cms/resources/js/Ametys/plugins/cms/content/helper/CopyContent.i18n.js
===================================================================
--- main/plugin-cms/resources/js/Ametys/plugins/cms/content/helper/CopyContent.i18n.js (revision 28821)
+++ main/plugin-cms/resources/js/Ametys/plugins/cms/content/helper/CopyContent.i18n.js (working copy)
@@ -351,7 +351,7 @@
},
waitMessage: {
msg: "",
- target: this._box.getEl()
+ target: this._box
},
errorMessage: {
category: Ext.getClassName(this) + '._ok',
Index: main/plugin-cms/resources/js/Ametys/plugins/cms/content/helper/CopyContentValues.i18n.js
===================================================================
--- main/plugin-cms/resources/js/Ametys/plugins/cms/content/helper/CopyContentValues.i18n.js (revision 28821)
+++ main/plugin-cms/resources/js/Ametys/plugins/cms/content/helper/CopyContentValues.i18n.js (working copy)
@@ -216,7 +216,7 @@
},
waitMessage: {
msg: "",
- target: this._box.getEl()
+ target: this._box
},
errorMessage: {
category: Ext.getClassName(this) + '._ok',
Index: main/plugin-cms/resources/js/Ametys/plugins/cms/content/tree/MetadataSetTree/MetadataSetNodeModel.i18n.js
===================================================================
--- main/plugin-cms/resources/js/Ametys/plugins/cms/content/tree/MetadataSetTree/MetadataSetNodeModel.i18n.js (revision 28821)
+++ main/plugin-cms/resources/js/Ametys/plugins/cms/content/tree/MetadataSetTree/MetadataSetNodeModel.i18n.js (working copy)
@@ -398,7 +398,6 @@
*/
metadataTooltipTpl: [
'
Index: main/plugin-cms/resources/js/Ametys/cms/content/ContentDAO.i18n.js
===================================================================
--- main/plugin-cms/resources/js/Ametys/cms/content/ContentDAO.i18n.js (revision 28821)
+++ main/plugin-cms/resources/js/Ametys/cms/content/ContentDAO.i18n.js (working copy)
@@ -165,9 +165,9 @@
* @param {Boolean} [fullContents=false] If `true`, the callback function receives a Content object as argument. If `false`, only the content id is provided.
* @param {String} [contentMessageTargetType=Ametys.message.MessageTarget#CONTENT] The message target factory role to use for the event of the bus thrown after content creation
* @param {String} [parentContentMessageTargetType=Ametys.message.MessageTarget#CONTENT] The message target factory role to use for the event of the bus thrown after parent content modification if applyable
* @param {Ext.Element} [waitMsgElt] The element that will be masked by the wait message
*/
- createContent: function (config, callback, scope, fullContents, contentMessageTargetType, parentContentMessageTargetType, waitMsgElt)
+ createContent: function (config, callback, scope, fullContents, contentMessageTargetType, parentContentMessageTargetType, waitMsgCmp)
{
// type, name and language are mandatory.
if (!config.contentType || !config.contentTitle || !config.contentLanguage)
@@ -218,7 +218,7 @@
parameters: params,
priority: Ametys.data.ServerComm.PRIORITY_MAJOR,
- waitMessage: {msg: "", target: waitMsgElt},
+ waitMessage: {msg: "", target: waitMsgCmp},
errorMessage: {
msg: "",
category: Ext.getClassName(this) + '.createContent'
@@ -165,9 +165,9 @@
* @param {String} [contentMessageTargetType=Ametys.message.MessageTarget#CONTENT] The message target factory role to use for the event of the bus thrown after content creation
* @param {String} [parentContentMessageTargetType=Ametys.message.MessageTarget#CONTENT] The message target factory role to use for the event of the bus thrown after parent content modification if applyable
- * @param {Ext.Element} [waitMsgElt] The element that will be masked by the wait message
+ * @param {Ext.Component} [waitMsgCmp] The component that will be masked by the wait message
*/